# Stack Overflow Data Analysis

[![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link] [![Streamlit][streamlit_badge]][streamlit_link]

Project used to learning Streamlit.

## Introduction

Learning to use Streamlit to show charts with Pandas, ...

### What this project can do

This project will answer some information about Stack Overflow.

These questions will be answered:

1. Percentagem of respondents who consider themselves professionals, non-professionals, students, hobbyists, etc.
2. Distribution of respondents by location. Which country had the most participation?
3. What is the respondent's distribution by level of education?
4. What is the distribution of working time for each type of professional informed in question 1?
5. Concerning people who work professionally:
    1. What is their profession?
    2. What is their level of education?
    3. What is the company's size of those people who work professionally?
6. The average salary of respondents?
7. Using the top five countries that have the most respondents, what is the salary of these people?
8. What is the percentage of people who work with Python?
9. About python:
    1. What is the salary level of people working with Python globally?
    2. In Brazil, what is the salary level?
    3. In the top five countries that have the most respondents, what is the salary level?
10. Concerning all respondents, what operating system do they use?
11. Concerning only people who work with Python, what operating system do they use?
12. What is the average age of respondents?
13. Concerning only people who work with Python, what is the average age?

This project is preferably installed with pipx:

```bash
pipx install streamlit_stackoverflow
```

[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/jpaulorc/streamlit_stackoverflow

[pypi_badge]: https://badgen.net/pypi/v/streamlit-stackoverflow?icon=pypi&color=black&label
[pypi_link]: https://pypi.org/project/streamlit-stackoverflow/

[streamlit_badge]: https://static.streamlit.io/badges/streamlit_badge_black_white.svg
[streamlit_link]: https://share.streamlit.io/jpaulorc/streamlit_stackoverflow/main/streamlit_stackoverflow/streamlit_app.py